It's amazing what the right small change can do when you're working on the order of billions of events. I reduced the frequency of get_context() calls during final confirmation (to get prevout block context for the purpose of evaluating relative locktime - which can be avoided if the relative locktime disabled bit is set in the sequence), which after 1 hour has yielded at 12% performance improvement.
(edited)